cumulusci.tasks.salesforce.tests package
========================================

Submodules
----------

cumulusci.tasks.salesforce.tests.test\_CreatePackage module
-----------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_CreatePackage
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_Deploy module
----------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_Deploy
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_DeployBundles module
-----------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_DeployBundles
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_EnsureRecordTypes module
---------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_EnsureRecordTypes
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_InstallPackageVersion module
-------------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_InstallPackageVersion
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_PackageUpload module
-----------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_PackageUpload
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_RetrievePackaged module
--------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_RetrievePackaged
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_RetrieveReportsAndDashboards module
--------------------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_RetrieveReportsAndDashboards
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_RetrieveUnpackaged module
----------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_RetrieveUnpackaged
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_SOQLQuery module
-------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_SOQLQuery
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_UninstallLocal module
------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallLocal
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_UninstallLocalBundles module
-------------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallLocalBundles
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_UninstallLocalNamespacedBundles module
-----------------------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallLocalNamespacedBundles
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_UninstallPackage module
--------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallPackage
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_UninstallPackaged module
---------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallPackaged
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_UninstallPackagedIncremental module
--------------------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallPackagedIncremental
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_UpdateAdminProfile module
----------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_UpdateAdminProfile
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_UpdateDependencies module
----------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_UpdateDependencies
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_base\_tasks module
---------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_base_tasks
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.test\_sourcetracking module
------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.test_sourcetracking
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.salesforce.tests.util module
--------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.tests.util
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.salesforce.tests
    :members:
    :undoc-members:
    :show-inheritance:
